@@ -5,13 +5,18 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.core._jsii
 import constructs._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-workspaces", "1.49.0", __name__[0:-6], "aws-workspaces@1.49.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "@aws-cdk/aws-workspaces",
+    "1.72.0",
+    __name__[0:-6],
+    "aws-workspaces@1.72.0.jsii.tgz",
+)
 
 __all__ = [
     "__jsii_assembly__",
